bayespy.inference.vmp.nodes.poisson.PoissonDistribution.plates_to_parent
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonDistribution.plates_to_parent